==> kmymoney-5.0.6-1.src.tar.gz: kmymoney-5.0.6/kmymoney/plugins/csv/export/csvexporter.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "aganders93@gmail.com",
                "Name": "Allan Anderson",
                "Name[ca@valencia]": "Allan Anderson",
                "Name[ca]": "Allan Anderson",
                "Name[cs]": "Allan Anderson",
                "Name[de]": "Allan Anderson",
                "Name[en_GB]": "Allan Anderson",
                "Name[es]": "Allan Anderson",
                "Name[fr]": "Allan Anderson",
                "Name[gl]": "Allan Anderson",
                "Name[it]": "Allan Anderson",
                "Name[nl]": "Allan Anderson",
                "Name[pl]": "Allan Anderson",
                "Name[pt]": "Allan Anderson",
                "Name[pt_BR]": "Allan Anderson",
                "Name[ru]": "Allan Anderson",
                "Name[sk]": "Allan Anderson",
                "Name[sv]": "Allan Anderson",
                "Name[uk]": "Allan Anderson",
                "Name[x-test]": "xxAllan Andersonxx"
            }
        ],
        "Description": "Add CSV exporting to KMyMoney",
        "Description[ca@valencia]": "Afig l'exportació a CSV al KMyMoney",
        "Description[ca]": "Afegeix l'exportació a CSV al KMyMoney",
        "Description[de]": "Fügt CSV-Export zu KMyMoney hinzu",
        "Description[en_GB]": "Add CSV exporting to KMyMoney",
        "Description[es]": "Añade exportación CSV a KMyMoney",
        "Description[fr]": "Ajoute l'exportation « CSV » à KMyMoney",
        "Description[gl]": "Engadir a posibilidade de exportar CSV desde KMyMoney",
        "Description[it]": "Aggiunge l'esportazione CSV a KMymoney",
        "Description[ko]": "KMyMoney에 CSV 내보내기를 추가",
        "Description[nl]": "Voeg CSV exporteren toe aan KMyMoney",
        "Description[pl]": "Dodaje eksportowanie CSV do KMyMoney",
        "Description[pt]": "Adição da exportação para CSV para o KMyMoney",
        "Description[pt_BR]": "Adiciona exportação CSV no KMyMoney",
        "Description[sk]": "Pridať CSV exportovanie do KMyMoney",
        "Description[sv]": "Lägg till CSV-export till KMyMoney",
        "Description[uk]": "Експортування даних CSV у KMyMoney",
        "Description[x-test]": "xxAdd CSV exporting to KMyMoneyxx",
        "EnabledByDefault": true,
        "Icon": "document-export",
        "Id": "csvexporter",
        "License": "GPL",
        "Name": "CSV Exporter",
        "Name[ca@valencia]": "Exportador a CSV",
        "Name[ca]": "Exportador a CSV",
        "Name[cs]": "Exportér CSV",
        "Name[de]": "CSV-Export",
        "Name[en_GB]": "CSV Exporter",
        "Name[es]": "Exportador CSV",
        "Name[fr]": "Exportateur de CSV",
        "Name[gl]": "Exportador a CSV",
        "Name[it]": "Strumento di esportazione CSV",
        "Name[nl]": "CSV-exportprogramma",
        "Name[pl]": "Eksporter CSV",
        "Name[pt]": "Exportação para CSV",
        "Name[pt_BR]": "Exportador CSV",
        "Name[sk]": "CSV exportér",
        "Name[sv]": "CSV-export",
        "Name[uk]": "Експортування CSV",
        "Name[x-test]": "xxCSV Exporterxx",
        "ServiceTypes": [
            "KMyMoney/Plugin"
        ],
        "Version": "@PROJECT_VERSION@@PROJECT_VERSION_SUFFIX@",
        "Website": "https://kmymoney.org/plugins.html"
    }
}

==> kmymoney-5.2.0-5.src.tar.gz: kmymoney-5.2.0/kmymoney/plugins/csv/export/csvexporter.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "aganders93@gmail.com",
                "Name": "Allan Anderson",
                "Name[ca@valencia]": "Allan Anderson",
                "Name[ca]": "Allan Anderson",
                "Name[cs]": "Allan Anderson",
                "Name[de]": "Allan Anderson",
                "Name[en_GB]": "Allan Anderson",
                "Name[eo]": "Allan Anderson",
                "Name[es]": "Allan Anderson",
                "Name[et]": "Allan Anderson",
                "Name[eu]": "Allan Anderson",
                "Name[fi]": "Allan Anderson",
                "Name[fr]": "Allan Anderson",
                "Name[gl]": "Allan Anderson",
                "Name[ia]": "Allan Anderson",
                "Name[it]": "Allan Anderson",
                "Name[ka]": "Allan Anderson",
                "Name[ko]": "Allan Anderson",
                "Name[nb]": "Allan Anderson",
                "Name[nl]": "Allan Anderson",
                "Name[pl]": "Allan Anderson",
                "Name[pt]": "Allan Anderson",
                "Name[pt_BR]": "Allan Anderson",
                "Name[ru]": "Allan Anderson",
                "Name[sk]": "Allan Anderson",
                "Name[sl]": "Allan Anderson",
                "Name[sv]": "Allan Anderson",
                "Name[uk]": "Allan Anderson",
                "Name[x-test]": "xxAllan Andersonxx",
                "Name[zh_CN]": "Allan Anderson",
                "Name[zh_TW]": "Allan Anderson"
            }
        ],
        "Description": "Add CSV exporting to KMyMoney",
        "Description[ca@valencia]": "Afig l'exportació cap a CSV a KMyMoney",
        "Description[ca]": "Afegeix l'exportació a CSV al KMyMoney",
        "Description[de]": "Fügt CSV-Export zu KMyMoney hinzu",
        "Description[en_GB]": "Add CSV exporting to KMyMoney",
        "Description[eo]": "Aldoni CSV-eksportadon al KMyMoney",
        "Description[es]": "Añade exportación CSV a KMyMoney",
        "Description[et]": "KMyMoney CVS eksportimine",
        "Description[eu]": "CSV esportazioa gehitzen dio KMyMoneyri ",
        "Description[fi]": "Lisää CSV-vienti KMyMoney-ohjelmaan",
        "Description[fr]": "Ajoute l'exportation « CSV » à KMyMoney",
        "Description[gl]": "Engadir a posibilidade de exportar CSV desde KMyMoney",
        "Description[ia]": "Adde exportar de CSV a KMyMoney",
        "Description[it]": "Aggiunge l'esportazione CSV a KMymoney",
        "Description[ka]": "KMyMoney-ში CSV გატანის დამატება",
        "Description[ko]": "KMyMoney에 CSV 내보내기 추가",
        "Description[nb]": "Legge til eksport av CSV i KMyMoney",
        "Description[nl]": "Voeg CSV exporteren toe aan KMyMoney",
        "Description[pl]": "Dodaje eksportowanie CSV do KMyMoney",
        "Description[pt]": "Adição da exportação para CSV para o KMyMoney",
        "Description[pt_BR]": "Adiciona exportação CSV no KMyMoney",
        "Description[ru]": "Добавляет в KMyMoney возможность экспорта CSV",
        "Description[sk]": "Pridať CSV exportovanie do KMyMoney",
        "Description[sl]": "Doda izvoz CSV v KMyMoney",
        "Description[sv]": "Lägg till CSV-export till KMyMoney",
        "Description[uk]": "Експортування даних CSV у KMyMoney",
        "Description[x-test]": "xxAdd CSV exporting to KMyMoneyxx",
        "Description[zh_CN]": "为 KMyMoney 添加 CSV 导出服务",
        "Description[zh_TW]": "提供 CSV 匯出功能給 KMyMoney",
        "EnabledByDefault": true,
        "Icon": "document-export",
        "Id": "csvexporter",
        "License": "GPL",
        "Name": "CSV Exporter",
        "Name[ca@valencia]": "Exportador a CSV",
        "Name[ca]": "Exportador a CSV",
        "Name[cs]": "Exportér CSV",
        "Name[de]": "CSV-Export",
        "Name[en_GB]": "CSV Exporter",
        "Name[eo]": "CSV-Eksportilo",
        "Name[es]": "Exportador CSV",
        "Name[et]": "CVS eksportija",
        "Name[eu]": "CSV esportatzea",
        "Name[fi]": "CSV-vienti",
        "Name[fr]": "Exportateur de CSV",
        "Name[gl]": "Exportador a CSV",
        "Name[ia]": "Exportator de CSV",
        "Name[it]": "Strumento di esportazione CSV",
        "Name[ka]": "CSV გამტანი",
        "Name[ko]": "CSV 내보내기 도구",
        "Name[nb]": "CSV-eksport",
        "Name[nl]": "CSV-exportprogramma",
        "Name[pl]": "Eksporter CSV",
        "Name[pt]": "Exportação para CSV",
        "Name[pt_BR]": "Exportador CSV",
        "Name[ru]": "Экспорт CSV",
        "Name[sk]": "CSV exportér",
        "Name[sl]": "Izvoznik CSV",
        "Name[sv]": "CSV-export",
        "Name[tr]": "CSV Dışa Aktarıcısı",
        "Name[uk]": "Експортування CSV",
        "Name[x-test]": "xxCSV Exporterxx",
        "Name[zh_CN]": "CSV 导出工具",
        "Name[zh_TW]": "CSV 匯出工具",
        "Version": "@PROJECT_VERSION@@PROJECT_VERSION_SUFFIX@",
        "Website": "https://kmymoney.org/plugins.html"
    }
}
